@@ -171,6 +171,8 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
         self.is_drop_corr = self.is_drop_corr if is_drop_corr is None else is_drop_corr
         self.label_first = self.label_first if label_first is None else label_first
         self.info_first = self.info_first if info_first is None else info_first
+        if self.label_first:
+            self.info_first = False
         self.corr = self.corr if corr is None else corr
         self.after_pretreatment = self.after_pretreatment if after_pretreatment is None else after_pretreatment
         self.init_box = self.init_box if init_box is None else init_box
