@@ -40,7 +40,7 @@ def is_assets(data: pd.Series) -> bool:
     indexes = data.value_counts().index[:min_is_structure_nums]
     for index in indexes:
         nums = re.findall(r'\d+', str(index))
-        types = re.findall(r'[^\d]+', str(index))
+        types = re.findall(r'\D+', str(index))
         if len(types) < 2 or (len(nums) != len(types)):
             return False
     return True
@@ -89,7 +89,7 @@ def deal_with_structure(
         data[col] = data[col].map(lambda x: sum(list(map(int, re.findall(r'\d+', str(x))))))
         return
     s = str(data[col][data[col].first_valid_index()]).replace('+', '')
-    types = re.findall(r'[^\d]+', s)
+    types = re.findall(r'\D+', s)
     if form == 'separate':
         structure_copy.append(col)
         for i in range(len(types)):
@@ -572,7 +572,7 @@ class DataPretreatment:
         for col in obj_col:
             try:
                 data[col] = data[col].astype(float)
-            except ValueError:
+            except (ValueError, TypeError):
                 unique_kind = data[col].unique()
                 type_dict = {}
                 obj_list = []
