@@ -90,7 +90,7 @@ def lgb_init(x_train, x_val, y_train, y_val, num_leaves, weight, epoch,
         else:
             lgb_evaluate_func = evaluate_func
         if version >= '3.3.0':
-            callbacks = [lgb.early_stopping(early_stopping), lgb.log_evaluation(1, show_stdv=False)]
+            callbacks = [lgb.early_stopping(early_stopping)]
             model = lgb.train(lgb_params, train_data, epoch, valid_sets=[train_data, val_data],
                               feval=lgb_evaluate_func, callbacks=callbacks)
         else:
@@ -98,7 +98,7 @@ def lgb_init(x_train, x_val, y_train, y_val, num_leaves, weight, epoch,
                               feval=lgb_evaluate_func, early_stopping_rounds=early_stopping, verbose_eval=False)
     else:
         if version >= '3.3.0':
-            callbacks = [lgb.early_stopping(early_stopping), lgb.log_evaluation(1, show_stdv=False)]
+            callbacks = [lgb.early_stopping(early_stopping)]
             model = lgb.train(lgb_params, train_data, epoch, valid_sets=[train_data, val_data],
                               callbacks=callbacks)
         else:
@@ -835,14 +835,6 @@ class ModelBuild:
     #         print('耗时:', round(end - start, 4))
     #     return opt_max_depth, opt_weight
 
-    def save_model(self, path):
-        if self.rfc_model is not None:
-            joblib.dump(self.rfc_model, path)
-        if self.lgb_model is not None:
-            joblib.dump(self.lgb_model, path)
-        if self.xgb_model is not None:
-            joblib.dump(self.xgb_model, path)
-
     def reset_atr(self):
         self.rfc_model = None
         self.lgb_model = None
